---
name: Bug report
about: Create a report to help us improve
title: ""
labels: bug
---

**Environment**

- Python Version
- kiota-serialization-json version:
- OS:

**Stack trace (if available)**
Screenshot or `formatted` copy and paste of your stack trace.

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:

**Expected behavior**
A clear and concise description of what you expected to happen.

**Screenshots**
If applicable, add screenshots to help explain your problem.

**Additional context**
Add any other context about the problem here.